require "yano/jquery/rails/engine"
require "yano/jquery/rails/version"

module Yano
  module Jquery
    module UI
      JS_COMPONENTS = {
        'core' => 'core',
        'widget' => 'widget',
        'mouse' => 'mouse',
        'position' => 'position',
        'draggable' => 'draggable',
        'droppable' => 'droppable',
        'resizable' => 'resizable',
        'selectable' => 'selectable',
        'sortable' => 'sortable',
        'accordion' => 'accordion',
        'autocomplete' => 'autocomplete',
        'button' => 'button',
        'datepicker' => 'datepicker',
        'datepicker-af' => 'i18n/datepicker-af',
        'datepicker-ar-DZ' => 'i18n/datepicker-ar-DZ',
        'datepicker-ar' => 'i18n/datepicker-ar',
        'datepicker-az' => 'i18n/datepicker-az',
        'datepicker-be' => 'i18n/datepicker-be',
        'datepicker-bg' => 'i18n/datepicker-bg',
        'datepicker-bs' => 'i18n/datepicker-bs',
        'datepicker-ca' => 'i18n/datepicker-ca',
        'datepicker-cs' => 'i18n/datepicker-cs',
        'datepicker-cy-GB' => 'i18n/datepicker-cy-GB',
        'datepicker-da' => 'i18n/datepicker-da',
        'datepicker-de' => 'i18n/datepicker-de',
        'datepicker-el' => 'i18n/datepicker-el',
        'datepicker-en-AU' => 'i18n/datepicker-en-AU',
        'datepicker-en-GB' => 'i18n/datepicker-en-GB',
        'datepicker-en-NZ' => 'i18n/datepicker-en-NZ',
        'datepicker-eo' => 'i18n/datepicker-eo',
        'datepicker-es' => 'i18n/datepicker-es',
        'datepicker-et' => 'i18n/datepicker-et',
        'datepicker-eu' => 'i18n/datepicker-eu',
        'datepicker-fa' => 'i18n/datepicker-fa',
        'datepicker-fi' => 'i18n/datepicker-fi',
        'datepicker-fo' => 'i18n/datepicker-fo',
        'datepicker-fr-CA' => 'i18n/datepicker-fr-CA',
        'datepicker-fr-CH' => 'i18n/datepicker-fr-CH',
        'datepicker-fr' => 'i18n/datepicker-fr',
        'datepicker-gl' => 'i18n/datepicker-gl',
        'datepicker-he' => 'i18n/datepicker-he',
        'datepicker-hi' => 'i18n/datepicker-hi',
        'datepicker-hr' => 'i18n/datepicker-hr',
        'datepicker-hu' => 'i18n/datepicker-hu',
        'datepicker-hy' => 'i18n/datepicker-hy',
        'datepicker-id' => 'i18n/datepicker-id',
        'datepicker-is' => 'i18n/datepicker-is',
        'datepicker-it-CH' => 'i18n/datepicker-it-CH',
        'datepicker-it' => 'i18n/datepicker-it',
        'datepicker-ja' => 'i18n/datepicker-ja',
        'datepicker-ka' => 'i18n/datepicker-ka',
        'datepicker-kk' => 'i18n/datepicker-kk',
        'datepicker-km' => 'i18n/datepicker-km',
        'datepicker-ko' => 'i18n/datepicker-ko',
        'datepicker-ky' => 'i18n/datepicker-ky',
        'datepicker-lb' => 'i18n/datepicker-lb',
        'datepicker-lt' => 'i18n/datepicker-lt',
        'datepicker-lv' => 'i18n/datepicker-lv',
        'datepicker-mk' => 'i18n/datepicker-mk',
        'datepicker-ml' => 'i18n/datepicker-ml',
        'datepicker-ms' => 'i18n/datepicker-ms',
        'datepicker-nb' => 'i18n/datepicker-nb',
        'datepicker-nl-BE' => 'i18n/datepicker-nl-BE',
        'datepicker-nl' => 'i18n/datepicker-nl',
        'datepicker-nn' => 'i18n/datepicker-nn',
        'datepicker-no' => 'i18n/datepicker-no',
        'datepicker-pl' => 'i18n/datepicker-pl',
        'datepicker-pt-BR' => 'i18n/datepicker-pt-BR',
        'datepicker-pt' => 'i18n/datepicker-pt',
        'datepicker-rm' => 'i18n/datepicker-rm',
        'datepicker-ru' => 'i18n/datepicker-ro',
        'datepicker-sk' => 'i18n/datepicker-sk',
        'datepicker-sl' => 'i18n/datepicker-sl',
        'datepicker-sq' => 'i18n/datepicker-sq',
        'datepicker-sr-SR' => 'i18n/datepicker-sr-SR',
        'datepicker-sr' => 'i18n/datepicker-sr',
        'datepicker-sv' => 'i18n/datepicker-sv',
        'datepicker-ta' => 'i18n/datepicker-ta',
        'datepicker-th' => 'i18n/datepicker-th',
        'datepicker-tj' => 'i18n/datepicker-tj',
        'datepicker-tr' => 'i18n/datepicker-tr',
        'datepicker-uk' => 'i18n/datepicker-uk',
        'datepicker-vi' => 'i18n/datepicker-vi',
        'datepicker-zh-CN' => 'i18n/datepicker-zh-CN',
        'datepicker-zh-HK' => 'i18n/datepicker-zh-HK',
        'datepicker-zh-TW' => 'i18n/datepicker-zh-TW',
        'dialog' => 'dialog',
        'menu' => 'menu',
        'progressbar' => 'progressbar',
        'selectmenu' => 'selectmenu',
        'slider' => 'slider',
        'spinner' => 'spinner',
        'tabs' => 'tabs',
        'tooltip' => 'tooltip',
        'effect-core' => 'effect',
        'effect-blind' => 'effect-blind',
        'effect-bounce' => 'effect-bounce',
        'effect-clip' => 'effect-clip',
        'effect-drop' => 'effect-drop',
        'effect-explode' => 'effect-explode',
        'effect-fade' => 'effect-fade',
        'effect-fold' => 'effect-fold',
        'effect-highlight' => 'effect-highlight',
        'effect-puff' => 'effect-puff',
        'effect-pulsate' => 'effect-pulsate',
        'effect-scale' => 'effect-scale',
        'effect-shake' => 'effect-shake',
        'effect-size' => 'effect-size',
        'effect-slide' => 'effect-slide',
        'effect-transfer' => 'effect-transfer'
      }

      CSS_COMPONENTS = %w(
        core accordion autocomplete button datepicker dialog draggable menu
        progressbar resizable selectable selectmenu sortable slider spinner tabs
        tooltip
      )
    end

    module Rails
    end
  end
end
